@@ -1,6 +1,7 @@
 import hashlib
 import unittest
 from base_repr import int_to_repr, repr_to_int, bytes_to_repr, repr_to_bytes, str_to_repr, repr_to_str
+from base_repr.functions import to_repr
 
 
 class TestCase(unittest.TestCase):
@@ -42,6 +43,16 @@ class TestCase(unittest.TestCase):
         for s in self.fixtures[2]:
             self.assertEqual(s, repr_to_str(str_to_repr(s)))
 
+    def test_to_repr(self):
+        for i in self.fixtures[0]:
+            self.assertEqual(to_repr(i), int_to_repr(i))
+
+        for b in self.fixtures[1]:
+            self.assertEqual(to_repr(b), bytes_to_repr(b))
+
+        for s in self.fixtures[2]:
+            self.assertEqual(to_repr(s), str_to_repr(s))
+
 
 if __name__ == '__main__':
     unittest.main()
